;; Generated package description from orderless.el  -*- no-byte-compile: t -*-
(define-package "orderless" "0.7" "Completion style for matching regexps in any order" '((emacs "26.1")) :commit "92008e762b30cb445a2227e458cbb9a5e1b1d4e8" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("extensions") :url "https://github.com/oantolin/orderless")
